@@ -16,7 +16,8 @@ from glob import glob
 from os.path import join
 
 import click
-from LbAPCommon import parse_yaml, render_yaml, validate_yaml
+import requests
+from LbAPCommon import get_api_token, parse_yaml, render_yaml, validate_yaml
 from LbAPCommon.checks import run_job_checks
 from LbAPCommon.checks_utils import checks_to_JSON, hist_to_root
 from pkg_resources import DistributionNotFound, get_distribution
@@ -25,6 +26,8 @@ from .checks import checks_exist, perform_checks
 from .log_parsing import show_log_advice
 from .testing import enter_debugging, prepare_reproduce, prepare_test
 from .utils import (
+    LBAPI_CLIENT_ID,
+    LBAPI_HOST,
     available_productions,
     check_production,
     inside_ap_datapkg,
@@ -63,6 +66,32 @@ def main():
     pass
 
 
+def wipe_token_cache(ctx, param, value):
+    if not value or ctx.resilient_parsing:
+        return
+    from LbAPCommon import wipe_token_cache
+
+    wipe_token_cache(LBAPI_CLIENT_ID)
+    click.secho("Token cache wiped successfully", fg="green")
+    ctx.exit()
+
+
+@main.command()
+@click.option(
+    "--wipe-cache",
+    is_flag=True,
+    callback=wipe_token_cache,
+    expose_value=False,
+    is_eager=True,
+)
+def login():
+    """Login to the Analysis Productions API"""
+    token = get_api_token(LBAPI_CLIENT_ID, f"{LBAPI_HOST}/user")
+    r = requests.get(f"{LBAPI_HOST}/user", headers={"Authorization": f"Bearer {token}"})
+    r.raise_for_status()
+    click.secho(f"Logged in successfully as {r.json()['username']}", fg="green")
+
+
 @main.command()
 @click.argument("production_name", type=production_name_type, default="", nargs=1)
 def list(production_name):
