@@ -14,11 +14,11 @@ from io import StringIO
 import click
 import consolemd
 from LbAPCommon.validators import explain_log
-from LbAPCommon.validators.logs import _spit_by_level
+from LbAPCommon.validators.logs import _split_by_level
 
 
 def show_log_advice(log_text, suppress=5):
-    log_messages = _spit_by_level(log_text)
+    log_messages = _split_by_level(log_text)
 
     _show_message_summary(log_messages, "FATAL", fg="red", bold=True)
     _show_message_summary(log_messages, "ERROR", fg="red")
