@@ -22,6 +22,9 @@ import click
 from LbAPCommon import write_jsroot_compression_options
 from LbAPCommon.hacks import setup_lbrun_environment
 
+LBAPI_HOST = os.environ.get("LBAPI_HOST", "https://lbap.app.cern.ch")
+LBAPI_CLIENT_ID = os.environ.get("LBAPI_CLIENT_ID", "lhcb-analysis-productions")
+
 
 def validate_environment():
     click.secho("Validating environment", fg="green")
