@@ -17,7 +17,7 @@ from LbAPLocal.cli import main
 def test_list(data_pkg_repo):
     runner = CliRunner()
     result = runner.invoke(main, ["list"])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
     assert "cbtesting" in result.stdout
     assert "BsToJpsiPhi" in result.stdout
     assert "RDs" in result.stdout
@@ -33,7 +33,7 @@ def test_list(data_pkg_repo):
 def test_list_with_production(data_pkg_repo, prod_name, example, num_expected):
     runner = CliRunner()
     result = runner.invoke(main, ["list", prod_name])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
     assert example in result.stdout
     assert result.stdout.count("\n*") == num_expected
 
@@ -42,7 +42,7 @@ def test_list_with_production(data_pkg_repo, prod_name, example, num_expected):
 def test_render(data_pkg_repo, prod_name):
     runner = CliRunner()
     result = runner.invoke(main, ["render", prod_name])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
 
 
 @pytest.mark.parametrize("prod_name", ["RDs"])
@@ -57,7 +57,7 @@ def test_render_bad(data_pkg_repo, prod_name):
 def test_validate(data_pkg_repo, prod_name):
     runner = CliRunner()
     result = runner.invoke(main, ["validate", prod_name])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
 
 
 @pytest.mark.parametrize("prod_name,expected_message", [("RDs", "output:")])
